@@ -14,7 +14,10 @@
 
 """Utility module."""
 
+import json
+
 from collections import OrderedDict
+from flask import Response
 
 
 def job_to_dict(job):
@@ -37,3 +40,15 @@ def job_to_dict(job):
         ]
 
     return OrderedDict(items)
+
+
+def jsonify(data, status=None):
+    return Response(json.dumps(data, indent=2), status=status, mimetype='application/json')
+
+
+def fix_job_def(job_def):
+    # it keeps compatibility backward
+    if isinstance(job_def.get('trigger'), dict):
+        trigger = job_def.pop('trigger')
+        job_def['trigger'] = trigger.pop('type', 'date')
+        job_def.update(trigger)
